ArxivLens
ArXiv cs.DB

Predicate Transfer: Efficient Pre-Filtering on Multi-Join Queries

Hangdong Zhao, Paraschos Koutris, Xiangyao Yu, Yifei Yang

2307.15255 Published Jul 31, 2023
Read paper View PDF
More tools
At a glance AI-generated · verify against the paper

This paper introduces predicate transfer, a method for optimizing multi-join query performance by pre-filtering tables to reduce join input sizes, outperforming Bloom join by 3.1x on average in TPC-H benchmarks. It generalizes Bloom join and theoretical results by Yannakakis to any join graphs using Bloom filters.

Abstract

This paper presents predicate transfer, a novel method that optimizes join performance by pre-filtering tables to reduce the join input sizes. Predicate transfer generalizes Bloom join, which conducts pre-filtering within a single join operation, to multi-table joins such that the filtering benefits can be significantly increased. Predicate transfer is inspired by the seminal theoretical results by Yannakakis, which uses semi-joins to pre-filter acyclic queries. Predicate transfer generalizes the theoretical results to any join graphs and use Bloom filters to replace semi-joins leading to significant speedup. Evaluation shows predicate transfer can outperform Bloom join by 3.1x on average on TPC-H benchmark.

AI Key Findings

Get AI-generated insights about this paper's methodology, results, significance, and more — available when analysis has been generated.

Paper preview View the original document Preview of the original paper

How to Cite This Paper

Reference manager: RIS EndNote

Discussion 0

This website uses cookies to ensure you get the best experience. Learn more